@@ -2,7 +2,7 @@ package plugins
 
 import (
 	"github.com/hashicorp/terraform-plugin-sdk/plugin"
-	"github.com/terraform-providers/terraform-provider-ignition/ignition"
+	"github.com/terraform-providers/terraform-provider-ignition/v2/ignition"
 )
 
 func init() {
